@@ -22,6 +22,7 @@ from tqdm.auto import tqdm
 
 from .result_mixin import ResultMixin
 from .utils import _get_function_name
+from .verbosity import VerbosityEnum
 
 LOGGER = logging.getLogger(__name__)
 
@@ -55,14 +56,16 @@ class AsyncResult:
         """Exposes the internal result object."""
         return self._result_object
 
-    def update(self, env: "GraphQLEnvironment", data: dict, progress_bar: tqdm = None):
-        """Updates the result object with the response data. Prints
-        any progress updates to the progress bar."""
+    def update(self, env: "GraphQLEnvironment", data: dict):
+        """Updates the result object with the response data."""
 
         env.update_data(self._field_type, self._result_object, data)
 
+    def print_progress(self, progress_bar: tqdm, verbosity: VerbosityEnum):
+        """Prints any progress updates to the progress bar."""
+
         # display progress message if required
-        if progress_bar is not None:
+        if verbosity == VerbosityEnum.VERBOSE and progress_bar is not None:
             message = self._get_progress_message()
 
             if message and message not in self._sent_messages:
@@ -129,7 +132,11 @@ class AsyncResultCollection:
         ]
 
     def update_data(
-        self, env: "GraphQLEnvironment", response_data: dict, progress_bar: tqdm
+        self,
+        env: "GraphQLEnvironment",
+        response_data: dict,
+        progress_bar: tqdm,
+        verbosity: VerbosityEnum,
     ):
         """Updates the related AsyncResult objects with the response data."""
 
@@ -145,7 +152,8 @@ class AsyncResultCollection:
 
         for index, async_result in enumerate(self._async_results):
             _response_data = response_data[index]
-            async_result.update(env, _response_data, progress_bar)
+            async_result.update(env, _response_data)
+            async_result.print_progress(progress_bar, verbosity)
 
     def finalize(self):
         """Reports on final status."""
