@@ -76,6 +76,8 @@ class ParallelExecutionCollector:
         refresh_query = MultiRefreshActionQuery(self._qctrl.gql_api, *refresh_queries)
 
         # wait for completion of all function calls
-        self._qctrl.gql_env.wait_for_completion(refresh_query, *self._async_results)
+        self._qctrl.gql_env.wait_for_completion(
+            refresh_query, *self._async_results, verbosity=self._qctrl.verbosity
+        )
 
         return True
